//Package:       RMIM - Functional Independence Measurement (FIM)
//Date Created : Nov 1,2002
//Site Name:     West Palm Beach VA Medical Center
//Developers:    John (Larry) McIntosh, Jerry Pickup, Cyndi McCracken
//Description:   Creates progress notes/consult responses and sends FIM
//               data to the FSOD database at AAC
unit Consult;

interface

uses
 Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
 StdCtrls, Buttons, ExtCtrls, Mfunstr;

type
 TfrmConsult = class(TForm)
  GroupBox5: TGroupBox;
  Panel3: TPanel;
  Label8: TLabel;
  Memo3: TMemo;
  fmListBoxPatNotes: TListBox;
  BtnOKConsult: TBitBtn;
  BitBtn4: TBitBtn;
  InvisiblefmListBoxPatNotes: TListBox;
  TempListBox: TListBox;
  procedure BtnOKConsultClick(Sender: TObject);
  procedure FormCreate(Sender: TObject);
  procedure ConvertfromMdate;
  procedure FormActivate(Sender: TObject);
    procedure BitBtn4Click(Sender: TObject);
 private
    { Private declarations }
 public
    { Public declarations }
 end;
 
var
 frmConsult: TfrmConsult;
 MDate: string;

implementation

uses Cpat, Main, Trpcb, uFIM_Objects;

{$R *.DFM}

procedure TfrmConsult.BtnOKConsultClick(Sender: TObject);
begin
 if fmListBoxPatNotes.ItemIndex <> -1 then
  begin
   MainForm.Consult_IEN := Piece(InvisiblefmListBoxPatNotes.items[fmListBoxPatNotes.ItemIndex], '^', 1);
   if MainForm.Consult_IEN = '' then
    begin
     MessageDlg('The Consult you selected has no Consult Number.' + #13 +
      'Please select another.', mtError, [mbOK], 0);
     ModalResult := 0;
     exit;
    end;
   MainForm.Consult := fmListBoxPatNotes.items[fmListBoxPatNotes.ItemIndex];
  end else
  begin
   MessageDlg('You failed to select a Consult.  Please try again.', mtconfirmation,
    [mbOK], 0);
   ModalResult := 0;
   exit;
  end;
 ModalResult := mrOK;
end;

procedure TfrmConsult.FormCreate(Sender: TObject);
var
 x: Integer;
begin
 If not FIMBroker.Connected then
  exit;
// LOAD ACTIVE CONSULTS
 MainForm.CheckDFN;
 FIMBroker.Param[0].PType := literal;
 FIMBroker.Param[0].Value := MainForm.PatientDFN;
 FIMBroker.Param[1].PType := literal;
 FIMBroker.Param[1].Value := '';
 FIMBroker.Param[2].PType := literal;
 FIMBroker.Param[2].Value := '';
 FIMBroker.Param[3].PType := literal;
 FIMBroker.Param[3].Value := '';
 FIMBroker.Param[4].PType := literal;
 FIMBroker.Param[4].Value := '2,5,6,8';
 FIMBroker.RemoteProcedure := MainForm.LoadConsultsCall;
 Try
  FIMBroker.Call;
  { check for errors on return}
 except
  on E:EBrokerError do
   begin
    ShowMessage('Broker Error: '+E.Message);
    exit;
   end;
  on E:EAccessViolation do
   begin
   ShowMessage(E.Message);
    exit;
   end;
  else
   begin
    raise;
    exit;
   end;
 end;
 InvisiblefmListBoxPatNotes.items := FIMBroker.Results;
 for x := 0 to (InvisiblefmListBoxPatNotes.Items.count - 1) do
  begin
   MDate := Piece(InvisiblefmListBoxPatNotes.items[x], '^', 2);
   ConvertfromMdate;
   MDate := Piece(MDate, '@', 1);
   fmListBoxPatNotes.items.add(MDate + '  ('+
   Piece(InvisiblefmListBoxPatNotes.items[x], '^', 3)+')  ' +
   Piece(InvisiblefmListBoxPatNotes.items[x], '^', 4));
  end;
end;

procedure TfrmConsult.ConvertfromMdate;
var
 ADate, ATime: string;
 DCent, DYear, DMonth, DDay, DHr, DMin: string;
 x: Integer;
begin
 DCent := Copy(MDate, 1, 1);
 if DCent = '2' then DCent := '19';
 if DCent = '3' then DCent := '20';
 ADate := Piece(MDate, '.', 1);
 DYear := Copy(ADate, 2, 2);
 DMonth := Copy(ADate, 4, 2);
 DDay := Copy(ADate, 6, 2);
 ATime := Piece(Mdate, '.', 2);
 DHr := Copy(ATime, 1, 2);
 DMin := Copy(ATime, 3, 2);
 x := Length(DMin);
 if x = 0 then DMin := '00';
 if x = 1 then DMin := DMin + '0';
 x := StrtoInt(DMonth);
 case x of
  1: DMonth := 'Jan';
  2: DMonth := 'Feb';
  3: DMonth := 'Mar';
  4: DMonth := 'Apr';
  5: DMonth := 'May';
  6: DMonth := 'Jun';
  7: DMonth := 'Jul';
  8: DMonth := 'Aug';
  9: DMonth := 'Sep';
  10: DMonth := 'Oct';
  11: DMonth := 'Nov';
  12: DMonth := 'Dec';
 end;
 MDate := DMonth + ' ' + DDay + ', ' + DCent + DYear + '@' + DHr + DMin;
end;

procedure TfrmConsult.FormActivate(Sender: TObject);
begin
 if fmListBoxPatNotes.Items.Count < 1 then
  begin
   Messagedlg('There are no consults for this patient.',
    mtInformation, [mbOK], 0);
   Close;
  end;
end;

procedure TfrmConsult.BitBtn4Click(Sender: TObject);
begin
 MainForm.Consult_IEN := '';
 MainForm.Consult := '';
end;

end.

