//Package:       RMIM - Functional Independence Measurement (FIM)
//Date Created : Nov 1,2002
//Site Name:     West Palm Beach VA Medical Center
//Developers:    John (Larry) McIntosh, Jerry Pickup, Cyndi McCracken
//Description:   Creates progress notes/consult responses and sends FIM
//               data to the FSOD database at AAC
unit Cpat;
                    
interface

uses
  SysUtils, WinTypes, WinProcs, Messages, Classes, Graphics, Controls, Inifiles,
  Forms, Dialogs, ExtCtrls, StdCtrls, Buttons, Trpcb, Menus, Spin, Clipbrd, Mfunstr;


type
  TfrmPatient = class(TForm)
    PatientWildCardEdit: TEdit;
    Label1: TLabel;
    RPCMemo: TMemo;
    GroupBox1: TGroupBox;
    pnlTitle: TPanel;
    lblPatients: TLabel;
    lblSource: TLabel;
    fmListBoxPatients: TListBox;
    btnCancel: TBitBtn;
    btnOKpat: TBitBtn;
    txtHelp2: TMemo;
    BitBtn1: TBitBtn;
    ListBox1: TListBox;
    WardListInv: TListBox;
    InvisiblefmListBoxPatients: TListBox;
    procedure btnOKpatClick(Sender: TObject);
    procedure PatientWildCardEditKeyPress(Sender: TObject; var Key: Char);
    procedure btnCancelClick(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure fmListBoxPatientsKeyPress(Sender: TObject; var Key: Char);
    procedure FormActivate(Sender: TObject);
  private
    { Private declarations }

  public
    { Public declarations }
  Status: String;
  RestrictedRecord : String;
  end;

var
  frmPatient: TfrmPatient;
  PatErrortrap : String;
  DFNHold: string;

implementation
  uses Main, frmDemoUnit, Warn2, uFIM_Objects;
{$R *.DFM}

procedure TfrmPatient.btnOKpatClick(Sender: TObject);
var A,B : string;
begin
 if fmListBoxPatients.ItemIndex <> -1 then
  begin
   MainForm.PatientDFN   := Piece(InvisiblefmListBoxPatients.items[fmListBoxPatients.ItemIndex],'^',1);
   MainForm.PatientName  := Piece(InvisiblefmListBoxPatients.items[fmListBoxPatients.ItemIndex],'^',2);
   MainForm.PatientDOB   := Piece(InvisiblefmListBoxPatients.items[fmListBoxPatients.ItemIndex],'^',3);
   MainForm.PatientSSN   := Piece(InvisiblefmListBoxPatients.items[fmListBoxPatients.ItemIndex],'^',4);
   MainForm.Sensitivity  := Piece(InvisiblefmListBoxPatients.items[fmListBoxPatients.ItemIndex],'^',5);
// check for duplicate names and last 4
   FIMBroker.Param[0].PType := literal;
   FIMBroker.Param[0].Value := MainForm.PatientDFN;
   FIMBroker.RemoteProcedure := MainForm.CheckMultiPatients;
   Try
    FIMBroker.Call;
     {check for errors on return}
   except
    on E:EBrokerError do
     begin
      ShowMessage('Broker Error: '+E.Message);
      exit;
     end;
    on E:EAccessViolation do
     begin
      ShowMessage(E.Message);
      exit;
     end;
   else
    begin
     raise;
     exit;
     end;
   end;
   If Piece(FIMBroker.Results[0],'^',1) = '1' then
    begin
     A := Piece(MainForm.PatientName,',',1);
     B := Copy(MainForm.PatientSSN,6,4);
     If MessageDlg('There is more than one patient whose last name is '+A+#13+
                   'and whose social security number ends with '+B+#13+
                   'Are you sure you wish to continue?',
        mtconfirmation,[mbyes,mbno],0) = mrno then
      exit;
    end;
   If (MainForm.PatientSSN = '*SENSITIVE*') and
      (Piece(InvisiblefmListBoxPatients.items[fmListBoxPatients.ItemIndex],'^',7) <> '') then
    begin
     MainForm.PatientDOB   := Piece(InvisiblefmListBoxPatients.items[fmListBoxPatients.ItemIndex],'^',6);
     MainForm.PatientSSN   := Piece(InvisiblefmListBoxPatients.items[fmListBoxPatients.ItemIndex],'^',7);
    end;
   If MainForm.PatientSSN ='' then exit;
{ check for restricted record
   -1 = error
    0 = regular record
    1 = sensitive record, user has key
    2 = sensitive record, user does not have key
    3 = trying to access own record}

 If (MainForm.Sensitivity <> '0') and (MainForm.Sensitivity <> '1') then
  begin
   If (MainForm.Sensitivity = '2') or (MainForm.Sensitivity = '3')  then
    begin
     If MainForm.Sensitivity = '2' then
      begin
       If Warning2 = nil then
        Application.createform(TWarning2, Warning2);
       Warning2.showmodal;
      end;
     If MainForm.Sensitivity = '3' then
      Showmessage('You may not access your own record.');
      If (RestrictedRecord = 'Y') or (MainForm.Sensitivity = '3') then
       begin
        FIMBroker.Param[0].PType := literal;
        FIMBroker.Param[0].Value := MainForm.PatientDFN;
        FIMBroker.RemoteProcedure := MainForm.RestrictedRecordCall;
        Try
         FIMBroker.Call;
         {check for errors on return}
        except
         on E:EBrokerError do
          begin
           ShowMessage('Broker Error: '+E.Message);
           exit;
          end;
         on E:EAccessViolation do
          begin
           ShowMessage(E.Message);
           exit;
          end;
         else
          begin
           raise;
           exit;
          end;
        end;
       end;
      If (RestrictedRecord = 'N') or (MainForm.Sensitivity = '3') then
       begin
      {clear variables }
        MainForm.PatientDFN  := '';
        MainForm.PatientName := '';
        MainForm.PatientDOB  := '';
        MainForm.PatientSSN := '';
        RestrictedRecord := '';
        Status := 'Cancel';
        ModalResult := mrCancel;
        Warning2.Free;
        Warning2 := nil;
        exit;
       end;
     Warning2.Free;
     Warning2 := nil;
    end;
  end;
 InvisiblefmListBoxPatients.Items.Clear;
 fmListBoxPatients.Items.Clear;

 {find patient's sex}
 FIMBroker.Param[0].PType := literal;
 FIMBroker.Param[0].Value := MainForm.PatientDFN;
 FIMBroker.RemoteProcedure := MainForm.GetPatientData;
 Try
  FIMBroker.Call;
   {check for errors on return}
 except
  on E:EBrokerError do
   begin
    ShowMessage('Broker Error: '+E.Message);
    exit;
   end;
  on E:EAccessViolation do
   begin
   ShowMessage(E.Message);
    exit;
   end;
  else
   begin
    raise;
    exit;
   end;
 end;
 MainForm.PatientRace          := Piece(FIMBroker.Results[0],'^',4);
 MainForm.PatientAge           := Piece(FIMBroker.Results[0],'^',5);
 MainForm.PatientSex           := Piece(FIMBroker.Results[0],'^',6);
 MainForm.PatientMaritalStatus := Piece(FIMBroker.Results[0],'^',7);
 MainForm.PatientActiveDuty    := Piece(FIMBroker.Results[0],'^',8);
 MainForm.P_Street             := Piece(FIMBroker.Results[0],'^',9);
 MainForm.P_City               := Piece(FIMBroker.Results[0],'^',10);
 MainForm.P_State              := Piece(FIMBroker.Results[0],'^',11);
 MainForm.P_Zip                := Piece(FIMBroker.Results[0],'^',12);
 MainForm.P_Phone              := Piece(FIMBroker.Results[0],'^',14);
// move data to form and database
 MainForm.lblName.Caption  := Mainform.PatientName;
 If MainForm.PatientSSN =  '*SENSITIVE*' then
  MainForm.lblSSN.Caption  := MainForm.PatientSSN;
 If MainForm.PatientSSN <> '*SENSITIVE*' then
 MainForm.lblSSN.Caption  := Copy(MainForm.PatientSSN,1,3)+'-'+
                          Copy(MainForm.PatientSSN,4,2)+'-'+
                          Copy(MainForm.PatientSSN,6,4);
 ModalResult := mrOK;
end else
 begin
  MessageDlg('You failed to select a patient.  Please try again.', mtconfirmation,
  [mbOK],0);
  Status :='Cancel';
  ModalResult := 0;
 end;
end;

procedure TfrmPatient.PatientWildCardEditKeyPress(Sender: TObject;
  var Key: Char);
VAR
K: Integer;
begin
 if key=chr(13) then
  begin
   If PatientWildCardEdit.Text = '' then
    begin
     Status := 'Cancel';
     ModalResult := mrOK;
     exit;
    end;
   If (Length(PatientWildCardEdit.Text) = 1) and (PatientWildCardEdit.Text <> ' ') then
    begin
     MessageDlg('Please enter more than one character.',mtinformation,[mbok],0);
     PatientWildCardEdit.Text := '';
     ModalResult := 0;
     exit;
    end;
    FIMBroker.Param[0].PType := literal;
    FIMBroker.Param[0].Value := PatientWildCardEdit.Text;
    FIMBroker.RemoteProcedure := MainForm.GetPatientCall;
    Try
    FIMBroker.Call;
     {check for errors on return}
    except
     on E:EBrokerError do
      begin
       ShowMessage('Broker Error: '+E.Message);
       Status := 'Cancel';
       ModalResult := mrOK;
       exit;
      end;
     on E:EAccessViolation do
      begin
       ShowMessage(E.Message);
       Status := 'Cancel';
       ModalResult := mrOK;
       exit;
      end;
     else
      begin
      raise;
      exit;
     end;
    end;
    GroupBox1.visible := true;
    GroupBox1.bringtofront;
    InvisiblefmListBoxPatients.Items.Clear;
    fmListBoxPatients.Items.Clear;
    InvisiblefmListBoxPatients.Items := FIMBroker.Results;
    if frmPatient.InvisiblefmListBoxPatients.items.count = 0 then
     fmListBoxPatients.items.add('    NO PATIENT(S) FOUND');
    for K:=0 to (frmPatient.InvisiblefmListBoxPatients.items.count-1) do
     begin
      fmListBoxPatients.items.add(Piece(InvisiblefmListBoxPatients.items[K],'^',4) +
       '          ' + Piece(InvisiblefmListBoxPatients.items[K],'^',2));
     end;
   BitBtn1.SendToBack;
   frmPatient.Height := 416;
   frmPatient.Position := poScreenCenter;
   frmPatient.Refresh;
   fmListBoxPatients.setfocus;
   If pos('NO PATIENT',fmListBoxPatients.Items[0]) <> 0 then
    begin
     PatientWildCardEdit.SetFocus;
     exit;
    end;
   If fmListBoxPatients.items.Count > 0 then
    fmListBoxPatients.ItemIndex := 0;
  end;
end;

procedure TfrmPatient.btnCancelClick(Sender: TObject);
begin
  Status := 'Cancel';
  ModalResult := mrOK;
end;

procedure TfrmPatient.FormCreate(Sender: TObject);
begin
 Status := '';
end;

procedure TfrmPatient.fmListBoxPatientsKeyPress(Sender: TObject;
  var Key: Char);
begin
 if key=chr(13) then btnOKPatClick(application);
end;

procedure TfrmPatient.FormActivate(Sender: TObject);
begin
 frmPatient.height := 135;
 frmPatient.Position := poScreenCenter;
 frmPatient.Refresh;
end;

end.
