//Package:       RMIM - Functional Independence Measurement (FIM)
//Date Created : Nov 1,2002
//Site Name:     West Palm Beach VA Medical Center
//Developers:    John (Larry) McIntosh, Jerry Pickup, Cyndi McCracken
//Description:   Creates progress notes/consult responses and sends FIM
//               data to the FSOD database at AAC
unit Note;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls, Buttons, ComCtrls, TRPCB, Mfunstr, ExtCtrls, CheckLst;

type
  TfrmNote = class(TForm)
    SendBtn: TBitBtn;
    BitBtn2: TBitBtn;
    InvisibleListBoxVisits: TListBox;
    Panel2: TPanel;
    GroupBox7: TGroupBox;
    Label1: TLabel;
    GroupBox4: TGroupBox;
    Edit1: TEdit;
    AuthorBtn: TBitBtn;
    GroupBox5: TGroupBox;
    BitBtn3: TBitBtn;
    Edit2: TEdit;
    GroupBox2: TGroupBox;
    RadioButton1: TRadioButton;
    RadioButton2: TRadioButton;
    RadioButton3: TRadioButton;
    ClinicLocations: TComboBox;
    GroupBox3: TGroupBox;
    ListBoxVisits: TListBox;
    PCEMemo: TMemo;
    NoteTitleSelection: TEdit;
    Label2: TLabel;
    InvisibleListBoxAdmits: TListBox;
    InvisibleListBoxHold: TListBox;
    InvisibleListBoxHold1: TListBox;
    GBDates: TGroupBox;
    FromDate: TDateTimePicker;
    ToDate: TDateTimePicker;
    Label3: TLabel;
    Label4: TLabel;
    edFrom: TEdit;
    edTo: TEdit;
    procedure ClearComponents(Sender: TObject);
    procedure RadioButton1Click(Sender: TObject);
    procedure RadioButton2Click(Sender: TObject);
    procedure RadioButton3Click(Sender: TObject);
    procedure GetVisits;
    procedure GetAdmissions;
    procedure GetLocations;
    procedure VistaBtnCheck;
    procedure ListBoxVisitsClick(Sender: TObject);
    procedure SendBtnClick(Sender: TObject);
    procedure CheckforCosigner;
    procedure AuthorBtnClick(Sender: TObject);
    procedure BitBtn3Click(Sender: TObject);
    procedure FormActivate(Sender: TObject);
    procedure ClinicLocationsKeyPress(Sender: TObject; var Key: Char);
    procedure ClinicLocationsClick(Sender: TObject);
    procedure BitBtn2Click(Sender: TObject);
    procedure SendNote;
    procedure FromDateChange(Sender: TObject);
    procedure ToDateChange(Sender: TObject);
    procedure ClinicLocationsChange(Sender: TObject);

  private
    { Private declarations }
  public
    { Public declarations }
    DT : String;
  end;

var
  frmNote: TfrmNote;
  ErrorFlag : Boolean;
  NoteErrorTrap : String;
  SendParam : String;
  VisitDate : String;
  VisitNo : String;
  TitleNo : String;
      one, two, three, four : String;
  Short : Integer;
  Long : Integer;
  CosignStatus : String;
  Cosigner : String;
  BrokerCall : string;
  MDate : String;
  Provider : Boolean;
  ProviderDuz : string;
  DT: string;
  NowDate: string;
  LastPrimary: integer;
  Consult_IEN : string;
implementation

uses Main, Auth, frmLookupUnit, uFIM_Objects;

{$R *.DFM}

procedure TFrmNote.ClearComponents(Sender: TObject);
var
  I: Integer;
begin
  for I := 0 to FrmNote.ComponentCount - 1 do
  begin
    if FrmNote.Components[I] is TListBox then
     TListBox(FrmNote.Components[i]).Clear;
    if FrmNote.Components[I] is TComboBox then
     TComboBox(FrmNote.Components[i]).Text := '';
    if FrmNote.Components[I] is TMemo then TMemo(FrmNote.Components[i]).Clear;
    if FrmNote.Components[I] is TEdit then
     TEdit(FrmNote.Components[i]).Text := '';
    if FrmNote.Components[I] is TCheckBox then TCheckBox(FrmNote.Components[i]).Checked := False;
    if FrmNote.Components[I] is TRadioButton then TRadioButton(FrmNote.Components[i]).Checked := False;
  end;
end;

procedure TfrmNote.RadioButton1Click(Sender: TObject);
var x : Integer;
    day, month, year, A : string;
begin
 SendBtn.Enabled := false;
 MainForm.VisitNo := '';
 VisitDate := '';
 ListBoxVisits.Clear;
 GetVisits;
// Appointments
 If RadioButton1.Checked then
  begin
   GBDates.Visible := true;
   For x := 0 to InvisibleListBoxVisits.items.count-1 do
    begin
     A := Piece(InvisibleListBoxVisits.items[x],'^',2);
     Day   := Copy(A,6,2);
     Month := Copy(A,4,2);
     Year  := Copy(A,2,2);
     ListBoxVisits.items.add(Month + '/' + Day + '/' + Year +
       '    ' + Piece(InvisibleListBoxVisits.items[x],'^',3)+
       ' - ' + Piece(InvisibleListBoxVisits.items[x],'^',4));
    end;
   end;
 If  ListBoxVisits.Items.Count = 0 then
  ListBoxVisits.items.add('Unable to locate appointments for this patient.');
// set up screen
 ListBoxVisits.Visible := true;
 ListBoxVisits.BringToFront;
 Label1.Caption := 'Clinic Appointments';
end;

procedure TfrmNote.RadioButton2Click(Sender: TObject);
var x : Integer;
    day, month, year, A : string;
begin
 GBDates.Visible := false;
 SendBtn.Enabled := false;
 MainForm.VisitNo := '';
 VisitDate := '';
 ListBoxVisits.Clear;
 GetAdmissions;
 for x := 0 to InvisibleListBoxAdmits.items.count-1 do
  begin
   A := Piece(InvisibleListBoxAdmits.items[x],'^',2);
   Day   := Copy(A,6,2);
   Month := Copy(A,4,2);
   Year  := Copy(A,2,2);
   ListBoxVisits.items.add(Month + '/' + Day + '/' + Year +
      '    ' + Piece(InvisibleListBoxAdmits.items[x],'^',3) +
      ' - ' + Piece(InvisibleListBoxAdmits.items[x],'^',4));
  end;
 If  ListBoxVisits.Items.Count = 0 then
  ListBoxVisits.items.add('Unable to locate admissions for this patient.');


// set up screen
 ListBoxVisits.Visible := true;
 ListBoxVisits.BringToFront;
 Label1.Caption := 'Hospital Admissions';
end;

procedure TfrmNote.RadioButton3Click(Sender: TObject);
begin
 GBDates.Visible := false;
 SendBtn.Enabled := false;
 MainForm.VisitNo := '';
 VisitDate := '';
 ListBoxVisits.Visible := false;
 try
  ClinicLocations.SetFocus;
 except
 end; 
 Label1.Caption := 'Type in a Location or at least the first 3 char; then press Enter:';
end;

procedure TfrmNote.GetVisits;
var One : string[1];
    x : Integer;
begin
   InvisibleListBoxVisits.Items.clear;
   InvisibleListBoxAdmits.Items.clear;
   InvisibleListBoxHold.Items.clear;
   InvisibleListBoxHold1.Items.clear;
   ListBoxVisits.items.clear;
   FIMBroker.Param[0].PType := literal;
   FIMBroker.Param[0].Value := MainForm.PatientDFN;
   FIMBroker.Param[1].PType := literal;
   FIMBroker.Param[1].Value := edFrom.Text;
   FIMBroker.Param[2].PType := literal;
   FIMBroker.Param[2].Value := edTo.Text+'.2359';
   FIMBroker.Param[3].PType := literal;
   FIMBroker.Param[3].Value := '1';
   FIMBroker.RemoteProcedure := MainForm.GetVisits;
   Try
    FIMBroker.Call;
    {check for errors on return}
   except
    on E:EBrokerError do
     begin
      ShowMessage('Broker Error: '+E.Message);
      exit;
     end;
    on E:EAccessViolation do
     begin
      ShowMessage(E.Message);
      exit;
     end;
    else
     begin
      raise;
      exit;
     end;
   end;
   InvisibleListBoxHold1.Items := FIMBroker.Results;
  For x := InvisibleListBoxHold1.Items.Count-1 downto 0 do
   InvisibleListBoxHold.items.Add(InvisibleListBoxHold1.Items[x]);
  For x := 0 to InvisibleListBoxHold.items.count-1 do
   begin
    One := InvisibleListBoxHold.Items[x];
    if (One = 'A') or (One = 'V') then
     InvisibleListBoxVisits.items.add(InvisibleListBoxHold.Items[x]);
    if One = 'I' then
     InvisibleListBoxAdmits.items.add(InvisibleListBoxHold.Items[x]);
   end;
end;

procedure TfrmNote.GetAdmissions;
var One : string[1];
    x : String;
    i : integer;
begin
   InvisibleListBoxVisits.Items.clear;
   InvisibleListBoxAdmits.Items.clear;
   InvisibleListBoxHold.Items.clear;
   InvisibleListBoxHold1.Items.clear;
   ListBoxVisits.items.clear;

//cd added to retrieve all admits
  FIMBroker.Param[0].PType := literal;
  FIMBroker.Param[0].Value := MainForm.PatientDFN;
  FIMBroker.RemoteProcedure := RPC_GetAdmits;
// end cd add

   Try
    FIMBroker.Call;
    {check for errors on return}
//showmessage('1. ' + FIMBroker.Results.Text);
   except
    on E:EBrokerError do
     begin
      ShowMessage('Broker Error: '+E.Message);
      exit;
     end;
    on E:EAccessViolation do
     begin
      ShowMessage(E.Message);
      exit;
     end;
    else
     begin
      raise;
      exit;
     end;
   end;

//cd added the following
   with FIMBroker do
   begin
     for i := 0 to Results.Count - 1 do
       begin
         x := Results[i];
         InvisibleListBoxAdmits.Items.Add('A;^' +
              (piece(x,'^',1)) + '^' +
              (piece(x,'^',3)) + '^' +
              (piece(x,'^',4)));

//         InvisibleListBoxHold.Items.Add('A;^' +
//              (piece(x,'^',1)) + '^' +
//              (piece(x,'^',3)) + '^' +
//              (piece(x,'^',4)));
      end;
    end;

{   FIMBroker.Param[0].PType := literal;
   FIMBroker.Param[0].Value := MainForm.PatientDFN;
   FIMBroker.Param[1].PType := literal;
   FIMBroker.Param[1].Value := '';
   FIMBroker.Param[2].PType := literal;
   FIMBroker.Param[2].Value := '';
   FIMBroker.Param[3].PType := literal;
   FIMBroker.Param[3].Value := '';
   FIMBroker.RemoteProcedure := MainForm.GetVisits;
   Try
    FIMBroker.Call;
    {check for errors on return}
{showmessage('2. ' + FIMBroker.Results.Text);
   except
    on E:EBrokerError do
     begin
      ShowMessage('Broker Error: '+E.Message);
      exit;
     end;
    on E:EAccessViolation do
     begin
      ShowMessage(E.Message);
      exit;
     end;
    else
     begin
      raise;
      exit;
     end;
   end;
}
   InvisibleListBoxHold1.Items := FIMBroker.Results;
  For i := InvisibleListBoxHold1.Items.Count-1 downto 0 do
   InvisibleListBoxHold.items.Add(InvisibleListBoxHold1.Items[i]);
  For i := 0 to InvisibleListBoxHold.items.count-1 do
   begin
    One := InvisibleListBoxHold.Items[i];
    if (One = 'V') then
//    if (One = 'A') or (One = 'V') then
     InvisibleListBoxVisits.items.add(InvisibleListBoxHold.Items[i]);
    if One = 'I' then
     InvisibleListBoxAdmits.items.add(InvisibleListBoxHold.Items[i]);
   end;
end;

procedure TfrmNote.GetLocations;
var k : Integer;
begin
   If BrokerCall = '' then exit;
   InvisibleListBoxVisits.Items.clear;
   ListBoxVisits.items.clear;
   FIMBroker.RemoteProcedure := BrokerCall;
   Try
    FIMBroker.Call;
    {check for errors on return}
   except
    on E:EBrokerError do
     begin
      ShowMessage('Broker Error: '+E.Message);
      exit;
     end;
    on E:EAccessViolation do
     begin
      ShowMessage(E.Message);
      exit;
     end;
    else
     begin
      raise;
      exit;
     end;
   end;
   InvisibleListBoxVisits.Items := FIMBroker.Results;
   For K:=0 to InvisibleListBoxVisits.items.count-1 do
    ClinicLocations.items.add(Piece(InvisibleListBoxVisits.items[K],'^',1));
end;

procedure TfrmNote.VistaBtnCheck;
begin
 If (RadioButton1.Checked) or (RadioButton2.Checked) then
  begin
   If (((ListBoxVisits.Visible = true)) and
      ((MainForm.VisitNo <> '') or (VisitDate <> '')) and (MainForm.TitleNo <> '')) and
      (((GroupBox5.Visible = true) and (Edit2.Text <> '')) or (GroupBox5.Visible = false)) then
    begin
     SendBtn.Enabled := true;
     SendBtn.SetFocus;
    end
   else
    SendBtn.Enabled := false;
   exit;
  end;
 If RadioButton3.Checked then
  begin
   If (ClinicLocations.Visible = true) and (MainForm.VisitLocation <> '') and
      (TitleNo <> '') then
    begin
     SendBtn.Enabled := true;
     If (GroupBox5.Visible = true) and (Edit2.Text = '') then SendBtn.Enabled := false;
     If SendBtn.Enabled then SendBtn.SetFocus;
    end
   else
    SendBtn.Enabled := false;
  end;
 If GroupBox2.Visible = false then
  begin
   If (MainForm.PatNoteNum <> '') {and (TitleNo <> '')} then
    begin
     SendBtn.Enabled := true;
     SendBtn.SetFocus;
    end
   else
    SendBtn.Enabled := false;
  end;
end;

procedure TfrmNote.ListBoxVisitsClick(Sender: TObject);
var A,B: string;
    C : string[4];
begin
 If (ListBoxVisits.Items[ListBoxVisits.ItemIndex] = 'Unable to locate appointments for this patient.') or
    (ListBoxVisits.Items[ListBoxVisits.ItemIndex] = 'Unable to locate admissions for this patient.') then
  exit;
 If RadioButton1.Checked then
  begin
   MainForm.VisitNo := '';
   A := Piece(InvisibleListBoxVisits.items[ListBoxVisits.ItemIndex],';',2);
   B := Piece(A,'.',1);
   C := Piece(A,'.',2);
   VisitDate := B + '.' + C;
   A := Piece(InvisibleListBoxVisits.items[ListBoxVisits.ItemIndex],'^',1);
   MainForm.VisitLocation := Piece(A,';',3);
   MainForm.VisitType := 'A';
  end;
 If RadioButton2.Checked then
  begin
   MainForm.VisitNo := '';
   A := Piece(InvisibleListBoxAdmits.items[ListBoxVisits.ItemIndex],';',2);
   B := Piece(A,'.',1);
   C := Piece(A,'.',2);
   VisitDate := B + '.' + C;
   A := Piece(InvisibleListBoxAdmits.items[ListBoxVisits.ItemIndex],'^',1);
   MainForm.VisitLocation := Piece(A,';',3);
//   VisitDate := Piece(InvisibleListBoxVisits.items[ListBoxVisits.ItemIndex],'^',1);
//   MainForm.VisitLocation := Piece(InvisibleListBoxVisits.items[ListBoxVisits.ItemIndex],'^',2);
   MainForm.VisitType := 'H';
  end;
 If GroupBox2.Visible = false then
  MainForm.PatNoteNum := Piece(InvisibleListBoxVisits.items[ListBoxVisits.ItemIndex],'^',1);
 VistaBtnCheck;
end;

procedure TfrmNote.SendBtnClick(Sender: TObject);
var Date : String;
    Time : String;
begin
 Consult_IEN := '';
 If CosignStatus <> 'OK' then
  begin
   {  check if cosigner is required  }
    CheckforCosigner;
    If CosignStatus = 'Yes' then
     If MainForm.Cosigner_Num = '' then exit;
  end;
  {set time for broker 24 hour format, no seconds};
 Date := DatetoStr(Now);
 DT := TimetoStr(now);
 Time := FormatDateTime('hh:nn',StrtoTime(DT));
 DT := Date+'@'+Time;
 If MainForm.Consult_IEN <> '' then
  begin
   Consult_IEN := MainForm.Consult_IEN+';GMR(123,';
   MainForm.NoteTitle := MainForm.NoteTitle;
   MainForm.TitleNo   := Mainform.FSODConsultIEN;
   SendNote;
  end;
 If MainForm.CallType = 'New Note' then
  begin
   // send to FSOD
   If MainForm.grpFacCode.Visible then
    begin
     If MainForm.NoteTitle <> MainForm.FSODConsultTitle then
      MainForm.NoteTitle := MainForm.FSODNoteTitle;
     TitleNo   := Mainform.FSODNoteIEN;
     Consult_IEN := '';
     SendNote;
    end;
   // don't send to FSOD
   If (MainForm.grpFacCode.Visible = false) and (Consult_IEN = '') then
    begin
     If MainForm.NoteTitle <> MainForm.FSODConsultTitle then
      MainForm.NoteTitle := MainForm.NonFSODNoteTitle;
     TitleNo   := Mainform.NonFSODNoteIEN;
     Consult_IEN := '';
     SendNote;
    end;
  end;
end;

procedure TfrmNote.CheckforCosigner;
var Param1, Param2, Param3, AuthorHold : String;
begin
 If TitleNo = '' then exit;
 Param1 := TitleNo;
 Param2 := '';
 Param3 := MainForm.Author_Num;
 FIMBroker.RemoteProcedure := MainForm.GetCosign;
 FIMBroker.Param[0].PType := Literal;
 FIMBroker.Param[0].Value := Param1;
 FIMBroker.Param[1].PType := Literal;
 FIMBroker.Param[1].Value := Param2;
 FIMBroker.Param[2].PType := Literal;
 FIMBroker.Param[2].Value := Param3;
 Try
  FIMBroker.Call;
   {check for errors on return}
 except
  on E:EBrokerError do
   begin
    ShowMessage('Broker Error: '+E.Message);
    exit;
   end;
  on E:EAccessViolation do
   begin
    ShowMessage(E.Message);
    exit;
   end;
  else
   begin
    raise;
    exit;
   end;
 end;
 If FIMBroker.Results[0] = '0' then
  begin
   CosignStatus := 'No';
   exit;
  end;
 If FIMBroker.Results[0] = '1' then
  begin
   CosignStatus := 'Yes';
   AuthorHold := MainForm.Author_Num;
   GroupBox5.Visible := true;
  end;
end;

procedure TfrmNote.AuthorBtnClick(Sender: TObject);
begin
 If not FIMBroker.Connected then MainForm.ConnectBroker(application);
 If not FIMBroker.Connected then exit;
 If frmAuthor = nil then
  frmAuthor := TfrmAuthor.Create(Application);
 frmAuthor.PatientWildCardEdit.text := '';
 frmAuthor.fmListBoxPatients.clear;
 frmAuthor.GroupBox1.visible := false;
 frmAuthor.showmodal ;
 frmAuthor.free;
 frmAuthor := nil;
 If MainForm.frmAuthorStatus = 'Cancel' then exit;
 MainForm.Author := MainForm.AuthorHold;
 MainForm.Author_Num := MainForm.Author_NumHold;
 Edit1.Text := MainForm.Author;
 VistaBtnCheck;
end;

procedure TfrmNote.BitBtn3Click(Sender: TObject);
begin
 If not FIMBroker.Connected then MainForm.ConnectBroker(application);
 If not FIMBroker.Connected then exit;
 If frmAuthor = nil then
  frmAuthor := TfrmAuthor.Create(Application);
 frmAuthor.PatientWildCardEdit.text := '';
 frmAuthor.fmListBoxPatients.clear;
 frmAuthor.GroupBox1.visible := false;
 frmAuthor.showmodal ;
 frmAuthor.free;
 frmAuthor := nil;
 If MainForm.frmAuthorStatus = 'Cancel' then exit;
 MainForm.Cosigner := MainForm.AuthorHold;
 MainForm.Cosigner_Num := MainForm.Author_NumHold;
 Edit2.text := MainForm.Cosigner;
 VistaBtnCheck;
end;

procedure TfrmNote.FormActivate(Sender: TObject);
begin
 frmNote.Caption := 'Progress Note';
 If MainForm.Consult_IEN <> '' then
  frmNote.Caption := 'Consult Completion';
 ClearComponents(application);
 ClinicLocations.Items.Clear;
 MainForm.VisitType := '';
 ToDate.Date := now+2;
 ToDateChange(application);
 FromDate.Date := now - 30;
 FromDateChange(application);
 Edit1.Text := MainForm.Author;
 frmNote.Refresh;
 GetVisits;
 RadioButton2.Checked := true;
 If (RadioButton2.Checked) and (ListBoxVisits.Items.Count = 0) then
  RadioButton2Click(application);
 groupbox3.bringtofront;
 NoteTitleSelection.Text := MainForm.NoteTitle;
 TitleNo := MainForm.TitleNo;
 CheckforCosigner;
end;

procedure TfrmNote.ClinicLocationsKeyPress(Sender: TObject;
  var Key: Char);
var K: Integer;
begin
 if key=chr(13) then
  begin
   FIMBroker.Param[0].PType := literal;
   If ClinicLocations.Text = '' then
    begin
     ModalResult := mrOK;
     exit;
    end;
   FIMBroker.Param[0].Value := ClinicLocations.Text;
   FIMBroker.RemoteProcedure := MainForm.GetLocationsCall;
   Try
    FIMBroker.Call;
    {check for errors on return}
   except
    on E:EBrokerError do
     begin
      ShowMessage('Broker Error: '+E.Message);
      exit;
     end;
    on E:EAccessViolation do
     begin
      ShowMessage(E.Message);
      exit;
     end;
    else
     begin
      raise;
      exit;
     end;
   end;
//   GroupBox1.visible := true;
   InvisibleListBoxVisits.Items.Clear;
   ClinicLocations.Items.Clear;
   InvisibleListBoxVisits.Items := FIMBroker.Results;
   for K:=0 to (InvisibleListBoxVisits.items.count-1) do
    begin
     ClinicLocations.items.add(Piece(InvisibleListBoxVisits.items[K],'^',2));
    end;
   ClinicLocations.Visible := true;
   ClinicLocations.setfocus;
  end;
end;

procedure TfrmNote.ClinicLocationsClick(Sender: TObject);
begin
 If InvisibleListBoxVisits.Items.Count < 1 then exit;
 If ClinicLocations.ItemIndex <> -1 then
  begin
   Try
    MainForm.VisitLocation := Piece(InvisibleListBoxVisits.items[ClinicLocations.ItemIndex],'^',1);
    VistaBtnCheck;
   except
   end;
  end;
end;

procedure TfrmNote.BitBtn2Click(Sender: TObject);
begin
 MainForm.Consult_IEN := '';
 MainForm.NoteStatus := 'Cancel';
end;

procedure TfrmNote.SendNote;
var x : Integer;
begin
   //   create visit and note
   MainForm.DateTime := DT;
   FIMBroker.Param[0].Value := DT;
   FIMBroker.Param[0].PType := literal;
   FIMBroker.RemoteProcedure := MainForm.GetNowCall;
   FIMBroker.Call;
   NowDate := FIMBroker.Results[0];
   FIMBroker.Param[0].ptype := literal;
   FIMBroker.Param[0].Value := MainForm.PatientDFN;
   FIMBroker.Param[1].ptype := literal;
   FIMBroker.Param[1].Value := TitleNo;
   FIMBroker.Param[2].ptype := literal;
   FIMBroker.Param[2].Value := '';
   FIMBroker.Param[3].ptype := literal;
   FIMBroker.Param[3].Value := '';
   FIMBroker.Param[4].ptype := literal;
   FIMBroker.Param[4].Value := '';
   FIMBroker.Param[5].PType := List;
   FIMBroker.Param[5].Value := '.X';
   FIMBroker.Param[5].Mult['.11']  := '1';
   FIMBroker.Param[5].Mult['1202'] := MainForm.Author_num;
   FIMBroker.Param[5].Mult['1205'] := MainForm.VisitLocation;
   // Added by DS RMIM*1*7 - adding cosigner to params sent in RPC
   if Edit2.Text <> '' then
      FIMBroker.Param[5].Mult['1208'] := MainForm.Cosigner_Num;
   FIMBroker.Param[5].Mult['1301'] := NOWDATE;
   FIMBroker.Param[5].Mult['1405'] := Consult_IEN;
   FIMBroker.Param[5].Mult['1701'] := '';
// check for admission or appointment
   If MainForm.VisitType = 'A' then
    sendparam := MainForm.Visitlocation + ';' + VisitDate + ';A';
   If MainForm.VisitType = 'H' then
    sendparam := MainForm.Visitlocation + ';' + VisitDate + ';H';
   If MainForm.VisitType = '' then
    sendparam := MainForm.Visitlocation + ';' + NOWDATE + ';A';
   FIMBroker.Param[6].PType := literal;
   FIMBroker.Param[6].Value := sendparam;
   FIMBroker.Param[7].PType := literal;
   FIMBroker.Param[7].Value := '1';
   FIMBroker.RemoteProcedure := MainForm.CreateNote;
   Try
    FIMBroker.Call;
    {check for errors on return}
   except
    on E:EBrokerError do
     begin
      ShowMessage('Broker Error: '+E.Message);
      exit;
     end;
    on E:EAccessViolation do
     begin
      ShowMessage(E.Message);
      exit;
     end;
    else
     begin
      raise;
      exit;
     end;
   end;
   If Piece(FIMBroker.Results[0],'^',1) = '0' then
    begin
     ShowMessage(Piece(FIMBroker.Results[0],'^',2));
     exit;
    end;
// progress note
   If Consult_IEN = '' then
    begin
     MainForm.NewPN_IEN := Piece(FIMBroker.Results[0], '^', 1);
     MainForm.TempPN_IEN := MainForm.NewPN_IEN;
     // lock tiu note
     MainForm.TIU_LockNote;
    end;
// consult
   If Consult_IEN <> '' then
    begin
     MainForm.Consul_IEN := Piece(FIMBroker.Results[0], '^', 1);
     MainForm.TempPN_IEN := MainForm.Consul_IEN;
     // lock tiu note
     MainForm.TIU_LockNote;
    end;
// add note text and update note
   FIMBroker.Param[0].ptype := literal;
   FIMBroker.Param[0].Value :=  MainForm.TempPN_IEN;
   FIMBroker.Param[1].PType := List;
   FIMBroker.Param[1].Value := '.X';
   FIMBroker.Param[1].Mult['.11'] := '0';
   FIMBroker.Param[1].Mult['1202'] := MainForm.Author_num;
   // Added by DS RMIM*1*7 - adding cosigner to params sent in RPC
   if Edit2.Text <> '' then
      FIMBroker.Param[1].Mult['1208'] := MainForm.Cosigner_Num;
   FIMBroker.Param[1].Mult['1301'] := NOWDATE;
   FIMBroker.Param[1].Mult['1405'] := Consult_IEN;
   FIMBroker.Param[1].Mult['1701'] := '';
   For x:=0 to MainForm.mem1.lines.count-1 do
   FIMBroker.Param[1].Mult['"TEXT",' + IntToStr(x+1) + ',0'] := MainForm.mem1.lines[x];
   FIMBroker.RemoteProcedure := MainForm.UpdateNote;
   Try
    FIMBroker.Call;
    {check for errors on return}
   except
    on E:EBrokerError do
     begin
      ShowMessage('Broker Error: '+E.Message);
      exit;
     end;
    on E:EAccessViolation do
     begin
      ShowMessage(E.Message);
      exit;
     end;
    else
     begin
      raise;
      exit;
     end;
   end;
   If Piece(FIMBroker.Results[0],'^',1) = '0' then
    begin
     ShowMessage(Piece(FIMBroker.Results[0],'^',2));
     exit;
    end;
   MainForm.NoteStatus := 'OK';
end;

procedure TfrmNote.FromDateChange(Sender: TObject);
begin
 edFrom.Text := DatetoStr(FromDate.Date);
 FIMBroker.Param[0].Value := edFrom.Text;
 FIMBroker.Param[0].PType := literal;
 FIMBroker.RemoteProcedure := MainForm.GetMDate;
 Try
  FIMBroker.Call;
   {check for errors on return}
 except
  on E:EBrokerError do
   begin
    ShowMessage('Broker Error: '+E.Message);
    exit;
   end;
  on E:EAccessViolation do
   begin
    ShowMessage(E.Message);
    exit;
   end;
  else
   begin
    raise;
    exit;
   end;
 end;
 edFrom.Text := FIMBroker.Results[0];
 GetVisits;
 If RadioButton1.Checked then RadioButton1Click(FromDate);
 If RadioButton2.Checked then RadioButton2Click(FromDate);
end;

procedure TfrmNote.ToDateChange(Sender: TObject);
begin
 edTo.Text := DatetoStr(ToDate.Date);
 FIMBroker.Param[0].Value := edTo.Text;
 FIMBroker.Param[0].PType := literal;
 FIMBroker.RemoteProcedure := MainForm.GetMDate;
 Try
  FIMBroker.Call;
   {check for errors on return}
 except
  on E:EBrokerError do
   begin
    ShowMessage('Broker Error: '+E.Message);
    exit;
   end;
  on E:EAccessViolation do
   begin
    ShowMessage(E.Message);
    exit;
   end;
  else
   begin
    raise;
    exit;
   end;
 end;
 edTo.Text := FIMBroker.Results[0];
 GetVisits;
 If RadioButton1.Checked then RadioButton1Click(ToDate);
 If RadioButton2.Checked then RadioButton2Click(ToDate);
end;

procedure TfrmNote.ClinicLocationsChange(Sender: TObject);
begin
 If ClinicLocations.Text = '' then
  begin
   MainForm.VisitLocation := '';
   VistaBtnCheck;
  end;
end;

end.
